Authors (dapclient)
===================
* Tim Cera, P.E. [tim@cerazone.net]

pydap Authors (sorted alphabetically)
=====================================
* Roberto De Almeida
* Michael Bunsen
* James Gallagher
* Aleksandar Jelenak
* Daniel Gray
* James Hiebert
* Stephan Hoyer
* [SiggyF](https://github.com/SiggyF)
* Aleksandar Jelenak
* [Tom Kralidis](https://github.com/tomkralidis)
* Frederic Laliberte
* Mike McCann
* Lewis John McGibbney
* [ocefpaf](https://github.com/ocefpaf)
* Ghislain Antony Vaillant
